<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns="http://www.w3.org/TR/xhtml1/strict"
    version='1.0'>
<!--
<xsl:output method="html" />
-->
<xsl:output indent="yes" />
<xsl:preserve-space elements="/" />
  <xsl:template match="/">
    <html>
    <head>
    <title><xsl:apply-templates select="krefty/title" /></title>
    <link rel="stylesheet" type="text/css" href="krefty.css" />
    <krefty /><!-- magic tag to identify a krefty file -->
    </head>
      <xsl:apply-templates select="krefty/author|krefty/description|krefty/copyright" />
    <body class="thebody">
    <div class="pagehead">
      <xsl:apply-templates select="krefty/title" />
    </div>
    <div class="odiv">
      <div class="spacer"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></div>
      <xsl:apply-templates select="krefty/introtext" />
      <div class="idiv">
        <xsl:apply-templates select="*/sect1[@side='left']" />
      </div>
      <div class="idivr">
        <xsl:apply-templates select="*/sect1[@side='right']" />
      </div>
      <xsl:apply-templates select="krefty/exittext" />
      <div class="spacer"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text></div>
    </div>
    <div class="pagefoot">
      <span class="infotext">
      <xsl:value-of disable-output-escaping="yes" select="krefty/info" />
      </span>
      <div style="text-align:right">
      <span class="infotext">&#169; <xsl:value-of select="krefty/copyright" /></span>
      </div>
    </div>
    </body>
    </html>
  </xsl:template>

  <xsl:template match="krefty/title">
      <xsl:value-of select="text()" />
  </xsl:template>

  <xsl:template match="krefty/introtext|krefty/exittext">
    <div class="idivfull">
      <xsl:value-of disable-output-escaping="yes" select="text()" />
    </div>
  </xsl:template>

  <xsl:template match="author">
    <xsl:comment> Author: "<xsl:value-of select="text()" />"  </xsl:comment>
  </xsl:template>
  <xsl:template match="description">
    <xsl:comment> Description: "<xsl:value-of select="text()" />"  </xsl:comment>
  </xsl:template>
  <xsl:template match="copyright">
    <xsl:comment> Copyright: "<xsl:value-of select="text()" />"  </xsl:comment>
  </xsl:template>

  <xsl:template match="*/sect1[@side='left']">
      <div class="rowl">
      <div class="secthead"><xsl:value-of select="title/text()" /></div>
      </div>
      <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="*/sect1[@side='right']">
      <div class="rowl">
      <div class="secthead"><xsl:value-of select="title/text()" /></div>
      </div>
      <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="*/sect2[title]">
    <div class="rowl">
    <div class="subsecthead"><xsl:value-of select="title" /></div>
    </div>
    <xsl:apply-templates />
  </xsl:template>

  <xsl:template match="*/hotkey">
    <div class="rowl">
      <div class="hkey">
        <span class="keyspan"><xsl:value-of select="key/text()" /></span>
        <span class="param"><xsl:value-of select="params/text()" /></span>
      </div>
      <div class="notes">
        <xsl:apply-templates select="desc" />
        <xsl:apply-templates select="note" />
      </div>
    </div>
  </xsl:template>

  <xsl:template match="command">
    <div class="rowl">
      <div class="cmd">
        <xsl:apply-templates select="cmd" />
      </div>
      <div class="notes">
        <xsl:apply-templates select="desc" />
        <xsl:apply-templates select="note" />
      </div>
    </div>
    <xsl:apply-templates select="./options" />
  </xsl:template>

  <xsl:template match="cmd">
        <span class="cmdspan"><xsl:value-of select="text()" /></span>
        <xsl:if test="string-length(../params/text()) > 0">
        <span class="param"><xsl:text disable-output-escaping="yes">&amp;nbsp;</xsl:text>
        <xsl:value-of select="../params/text()" /></span>
        </xsl:if>
        <xsl:text disable-output-escaping="yes">&lt;br /&gt;</xsl:text>
  </xsl:template>

  <xsl:template match="options">
    <xsl:for-each select="./option">
      <div class="rowl">
        <xsl:apply-templates select="." />
      </div>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="option">
      <div class="option">
        <span class="cmdspan"><xsl:value-of select="./flag/text()" /></span>
        <xsl:if test="./params">
        <span class="param"><xsl:value-of select="./params/text()" /></span>
        </xsl:if>
      </div>
      <div class="notes">
        <xsl:if test="string-length(./desc/text())>0">
          <xsl:apply-templates select="desc" />
          <xsl:apply-templates select="note" />
        </xsl:if>
      </div>
  </xsl:template>

  <xsl:template match="hotkey/note|command/note">
    <xsl:if test="string-length(text()) > 0">
    <img src="note.png" border="0" width="12" height="12" alt="Note" title="{text()}"/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="miscellanii">
    <div class="rowl">
      <div class="miscellanii">
        <xsl:value-of disable-output-escaping="yes" select="text()" />
      </div>
    </div>
  </xsl:template>

  <xsl:template match="desc">
    <span class="desc">
    <xsl:value-of disable-output-escaping="yes" select="text()" />
    </span>
  </xsl:template>

  <xsl:template match="text()">
  </xsl:template>

</xsl:stylesheet>
